ods pdf file='xx.pdf';
proc sort data=alldata;
  by varc cata;
run;
/*
proc print data=alldata;
var  varc cata x2 events catnobs cat1 hazardratio hruppercl hrlowercl medians;
run;
*/
data alldata2;
  set alldata;
  by varc cata;
length newvar $30;

newvar="  "||cat1;
newcat=cata;
output;
if last.varc and upcase(varc) ne 'OVERALL' then do;
  newvar=varc; 
  newcat=cata+0.1;
  hazardratio=.; hruppercl=.; hrlowercl=.; medians=.;events='';hr='';
  output;
end;


run;

proc print data=alldata2;
var newvar newcat varc cata x2 events hazardratio hruppercl hrlowercl medians;
run;


proc template;
define statgraph forestplot;
  dynamic _cat _x _y _lab1 _lab2 _lab3 _events _hr _upper
          _lower _hrvalue _hrlabel _ref = 1	_medians _evlabel;

  begingraph;
    layout lattice / columns=5 columnweights=(.30 .15 .25 .18 .12);
	/*labels  column 1*/
	   if (exists(_y))
	     layout OVERLAY / walldisplay=none border=false halign=center
	               yaxisopts=( display=none offsetmax=0.05 offsetmin=0.05 )
                   xaxisopts=(display=none );
              entry  halign=right " " /  location=outside valign=top textattrs=(size=8pt);                           
              entry  halign=left "Subgroup" /  location=outside valign=top textattrs=(size=8pt);                          
		      scatterplot y=_y x=eval(_x) / markercharacter=_y 
                          markercharacterattrs=(family='Lucida Console' size=6 weight=bold);
          endlayout;
       endif;
	/*events column2 */
	  if (exists(_events))
	    layout overlay / walldisplay=none border=false
	              yaxisopts=( display=none offsetmax=0.05 offsetmin=0.05 )
                  xaxisopts=(display=none );
             entry  halign=center _lab1 "   "   _lab2  /  location=outside valign=top textattrs=(size=8pt);                           
             entry  halign=center "--- " _evlabel " ---" /  location=outside valign=top textattrs=(size=8pt);                  
		     scatterplot y=_y x=eval(_x)  / markercharacter=_events ;
        endlayout;
	  endif;
     /* plot column 3 */
       layout overlay / walldisplay=none border=false
   	             yaxisopts=(display=none offsetmax=0.05 offsetmin=0.05  )
                 xaxisopts=( type=log label=(' ')  );
            entry  halign=left "Favours " _lab1 halign=right   " Favours "  _lab2  /  location=outside valign=bottom 
                      textattrs=(size=8pt);                           
            scatterplot y=_y x=_hr / XERRORUPPER=_upper Xerrorlower=_lower;
	 		referenceline x=_ref / lineattrs=(pattern=shortdash); 
	   endlayout;
     /* HR and CI column 4*/
	   if (exists(_HRvalue))
	     layout overlay / walldisplay=none border=false
	               yaxisopts=( display=none offsetmax=0.05 offsetmin=0.05 )
                   xaxisopts=(type=discrete display=none );
              entry  halign=Center _hrlabel /  location=outside valign=top textattrs=(size=8pt);         ;   
	          entry  halign=left "   " /  location=outside valign=top textattrs=(size=8pt);                  
  		      scatterplot y=_y x=eval(_x) / markercharacter=_HRvalue;
          endlayout;
		endif;
	/*medians column 5 */
	   if (exists(_medians))
	      layout overlay / walldisplay=none border=false
	             yaxisopts=( display=none offsetmax=0.05 offsetmin=0.05 )
                 xaxisopts=(display=none );
             entry  halign=right _lab1 "    " _lab2 /  location=outside valign=top textattrs=(size=8pt);                          
             entry  halign=right "-- " _lab3 " --" / location=outside valign=top textattrs=(size=8pt);                           
 		     scatterplot y=_y x=eval(_x)  / markercharacter=_medians ;
           endlayout;
       endif;
    endlayout;*end lattice;
  endgraph;
end;
run;

proc sgrender data=alldata2 template=ForestPlot ; 
            dynamic _x       = 'x2'
                    _y       = 'newvar' 
					_lab1    = 'Drug'
					_lab2    = 'Comp'
					_events  = 'events'
					_evlabel = 'Events/N'
					_hr      = 'hazardratio'
					_upper   = 'HRUpperCL'
					_lower   = 'HRLowerCL'
					_hrvalue = 'HR'
					_hrlabel = 'HR (LCL, UCL)'
					_ref     = '1'
					_medians = 'Medians'
					_lab3    = 'Median'
            ; run; 
ods pdf close;
